@@ -25,7 +25,7 @@ language_support = {
     'py': 'hash',
     'sh': 'hash',
     'java': 'slash',
-    'tf': 'hash',
+    'tf': 'slash',
 }
 
 file_support = {
@@ -59,7 +59,7 @@ def get_all_files(path):
     paths = []
     for tree in trees:
       for blob in tree.blobs:
-        if not matches or not matches(blob.abspath) and get_copyright_file(path, blob.abspath):
+        if (not matches or not matches(blob.abspath)) and get_copyright_file(path, blob.abspath):
           paths.append(blob.abspath)
       if tree.trees:
         paths.extend(get_tracked_files(tree.trees))
